[OE-core] [PATCH] oeqa: fix typo

Humberto Ibarra humberto.ibarra.lopez at intel.com
Mon Feb 13 17:25:37 UTC 2017


The word 'uninstall' was spelled incorrectly in various parts of
oeqa files.

Signed-off-by: Humberto Ibarra <humberto.ibarra.lopez at intel.com>
---
 meta-selftest/lib/oeqa/runtime/cases/selftest.py |  6 +++---
 meta/lib/oeqa/oetest.py                          | 12 ++++++------
 meta/lib/oeqa/selftest/runtime-test.py           |  2 +-
 meta/lib/oeqa/utils/package_manager.py           |  4 ++--
 4 files changed, 12 insertions(+), 12 deletions(-)

diff --git a/meta/lib/oeqa/oetest.py b/meta/lib/oeqa/oetest.py
index b886130..a89bd11 100644
--- a/meta/lib/oeqa/oetest.py
+++ b/meta/lib/oeqa/oetest.py
@@ -106,7 +106,7 @@ class oeRuntimeTest(oeTest):
         pass
 
     def tearDown(self):
-        # Unistall packages in the DUT
+        # Uninstall packages in the DUT
         self.tc.install_uninstall_packages(self.id(), False)
 
         res = getResults()
@@ -546,7 +546,7 @@ class RuntimeTestContext(TestContext):
 
     def install_uninstall_packages(self, test_id, pkg_dir, install):
         """
-        Check if the test requires a package and Install/Unistall it in the DUT
+        Check if the test requires a package and Install/Uninstall it in the DUT
         """
 
         test = test_id.split(".")[4]
@@ -559,7 +559,7 @@ class RuntimeTestContext(TestContext):
 
     def _install_uninstall_packages(self, needed_packages, pkg_dir, install=True):
         """
-        Install/Unistall packages in the DUT without using a package manager
+        Install/Uninstall packages in the DUT without using a package manager
         """
 
         if isinstance(needed_packages, dict):
@@ -577,7 +577,7 @@ class RuntimeTestContext(TestContext):
             if install and extract:
                 self.target.connection.copy_dir_to(src_dir, "/")
 
-            # Unistall package
+            # Uninstall package
             elif not install and rm:
                 self.target.connection.delete_dir_structure(src_dir, "/")
 
@@ -600,7 +600,7 @@ class ImageTestContext(RuntimeTestContext):
 
     def install_uninstall_packages(self, test_id, install=True):
         """
-        Check if the test requires a package and Install/Unistall it in the DUT
+        Check if the test requires a package and Install/Uninstall it in the DUT
         """
 
         pkg_dir = self.d.getVar("TEST_EXTRACTED_DIR")
@@ -623,7 +623,7 @@ class ExportTestContext(RuntimeTestContext):
 
     def install_uninstall_packages(self, test_id, install=True):
         """
-        Check if the test requires a package and Install/Unistall it in the DUT
+        Check if the test requires a package and Install/Uninstall it in the DUT
         """
 
         export_dir = os.path.dirname(os.path.dirname(os.path.realpath(__file__)))
diff --git a/meta/lib/oeqa/selftest/runtime-test.py b/meta/lib/oeqa/selftest/runtime-test.py
index 52e5b27..a673f36 100644
--- a/meta/lib/oeqa/selftest/runtime-test.py
+++ b/meta/lib/oeqa/selftest/runtime-test.py
@@ -102,7 +102,7 @@ class TestImage(oeSelfTest):
         """
         Summary: Check install packages functionality for testimage/testexport.
         Expected: 1. Import tests from a directory other than meta.
-                  2. Check install/unistall of socat.
+                  2. Check install/uninstall of socat.
         Product: oe-core
         Author: Mariano Lopez <mariano.lopez at intel.com>
         """
diff --git a/meta/lib/oeqa/utils/package_manager.py b/meta/lib/oeqa/utils/package_manager.py
index 9264648..724afb2 100644
--- a/meta/lib/oeqa/utils/package_manager.py
+++ b/meta/lib/oeqa/utils/package_manager.py
@@ -187,7 +187,7 @@ def test_needs_package(test_case):
 
 def _install_uninstall_packages(needed_packages, test_case, install=True):
     """
-    Install/Unistall packages in the DUT without using a package manager
+    Install/Uninstall packages in the DUT without using a package manager
     """
 
     if isinstance(needed_packages, dict):
@@ -205,6 +205,6 @@ def _install_uninstall_packages(needed_packages, test_case, install=True):
         if install and extract:
             test_case.tc.target.copyDirTo(src_dir, '/')
 
-        # Unistall package
+        # Uninstall package
         elif not install and rm:
             test_case.tc.target.deleteDirStructure(src_dir, '/')
diff --git a/meta-selftest/lib/oeqa/runtime/cases/selftest.py b/meta-selftest/lib/oeqa/runtime/cases/selftest.py
index 329470f..19de740 100644
--- a/meta-selftest/lib/oeqa/runtime/cases/selftest.py
+++ b/meta-selftest/lib/oeqa/runtime/cases/selftest.py
@@ -8,7 +8,7 @@ class Selftest(OERuntimeTestCase):
         """
         Summary: Check basic package installation functionality.
         Expected: 1. Before the test socat must be installed using scp.
-                  2. After the test socat must be unistalled using ssh.
+                  2. After the test socat must be uninstalled using ssh.
                      This can't be checked in this test.
         Product: oe-core
         Author: Mariano Lopez <mariano.lopez at intel.com>
@@ -18,10 +18,10 @@ class Selftest(OERuntimeTestCase):
         self.assertEqual(status, 0, msg="socat is not installed")
 
     @OETestDepends(['selftest.Selftest.test_install_package'])
-    def test_verify_unistall(self):
+    def test_verify_uninstall(self):
         """
         Summary: Check basic package installation functionality.
         Expected: 1. test_install_package must unistall socat.
                      This test is just to verify that.
         Product: oe-core
         Author: Mariano Lopez <mariano.lopez at intel.com>
@@ -18,10 +18,10 @@ class Selftest(OERuntimeTestCase):
         """
         Summary: Check basic package installation functionality.
-        Expected: 1. test_install_package must unistall socat.
+        Expected: 1. test_install_package must uninstall socat.
                      This test is just to verify that.
         Product: oe-core
-- 
2.7.4




More information about the Openembedded-core mailing list